import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/responsive/responsive.dart';

class SplitScreen extends StatelessWidget {
  final Widget leftChild;
  final Widget rightChild;
  final Image? logo;
  final String? logoText;
  final Image? backgroundImage;
  final Widget? footer;
  final Color? backgroundColor;

  const SplitScreen({
    Key? key,
    required this.leftChild,
    required this.rightChild,
    this.backgroundImage,
    this.footer,
    this.backgroundColor,
    this.logo,
    this.logoText,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: backgroundColor ?? defaultBackgroundColor,
      body: Container(
        constraints: BoxConstraints(minHeight: MediaQuery.of(context).size.height),
        child: SafeArea(
        child: SingleChildScrollView(
          child: Column(
            children: [
              if (logo != null && !Responsive.isDesktop(context))
                Padding(
                  padding: const EdgeInsets.all(defaultPadding),
                  child: Align(
                    child: Column(
                      children: [
                        Image(
                          image: logo!.image,
                          height: 55,
                        ),
                        const SizedBox(height: 5),
                        Text(
                          logoText ?? "",
                          style: const TextStyle(
                            color: Colors.black,
                            fontSize: 22,
                            fontWeight: FontWeight.w600,
                          ),
                        )
                      ],
                    ),
                    alignment: Alignment.topLeft,
                  ),
                ),
              IntrinsicHeight(
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    if (Responsive.isDesktop(context))
                      Expanded(
                        flex: 1,
                        child: Container(
                          decoration: backgroundImage != null
                              ? BoxDecoration(
                                  image: DecorationImage(
                                    image: backgroundImage!.image,
                                    fit: BoxFit.cover,
                                  ),
                                )
                              : const BoxDecoration(
                                  gradient:
                                      LinearGradient(colors: darkGradient),
                                ),
                          child: Column(
                            children: [
                              if (logo != null && Responsive.isDesktop(context))
                                Padding(
                                  padding: const EdgeInsets.all(defaultPadding),
                                  child: Align(
                                    child: Column(
                                      children: [
                                        Image(
                                          image: logo!.image,
                                          height: 55,
                                          color: Colors.white,
                                        ),
                                        const SizedBox(height: 5),
                                        Text(
                                          logoText ?? "",
                                          style: const TextStyle(
                                            color: Colors.white,
                                            fontSize: 22,
                                            fontWeight: FontWeight.w600,
                                          ),
                                        )
                                      ],
                                    ),
                                    alignment: Alignment.topLeft,
                                  ),
                                ),
                              leftChild,
                            ],
                          ),
                        ),
                      ),
                    Expanded(
                      flex: 1,
                      child: rightChild,
                    ),
                  ],
                ),
              ),
              if (!Responsive.isDesktop(context))
                Container(
                  decoration: backgroundImage != null
                      ? BoxDecoration(
                          image: DecorationImage(
                            image: backgroundImage!.image,
                            fit: BoxFit.cover,
                          ),
                        )
                      : const BoxDecoration(
                          gradient: LinearGradient(colors: darkGradient),
                        ),
                  child: leftChild,
                ),
              footer ?? const SizedBox(),
            ],
          ),
        ),
      ),
      ),
    );
  }
}

class LeftChild extends StatelessWidget {
  final ImageProvider? backgroundImage;
  final Widget? leftChild;
  final double? height;
  final Widget? leftCornerLogo;
  final double? logoSize;

  const LeftChild({
    Key? key,
    required this.height,
    required this.leftCornerLogo,
    required this.backgroundImage,
    required this.leftChild,
    required this.logoSize,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Flexible(
      flex: Responsive.isMobile(context) ? 1 : 4,
      child: Container(
        height: height,
        width: Responsive.isMobile(context) ? size.width : size.width / 2,
        decoration: BoxDecoration(
          image: DecorationImage(
            image:
                backgroundImage ?? const AssetImage("assets/covers/cover1.jpg"),
            fit: BoxFit.cover,
          ),
        ),
        child: Stack(
          children: [
            Padding(
                padding: EdgeInsets.only(top: logoSize ?? 0.0),
                child: leftChild ?? const SizedBox()),
            !Responsive.isMobile(context)
                ? Align(
                    alignment: Alignment.topLeft,
                    child: Padding(
                        padding: const EdgeInsets.all(defaultPadding),
                        child: SizedBox(
                          height: logoSize,
                          child: leftCornerLogo,
                        )),
                  )
                : const SizedBox(),
          ],
        ),
      ),
    );
  }
}

class RightChild extends StatelessWidget {
  final Widget? rightChild;
  final double? height;

  const RightChild({
    Key? key,
    required this.height,
    this.rightChild,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Flexible(
      flex: 4,
      child: SizedBox(
        height: height,
        width: Responsive.isMobile(context) ? size.width : size.width / 2,
        child: !Responsive.isMobile(context)
            ? SingleChildScrollView(
                child: rightChild ?? const SizedBox(),
              )
            : rightChild ?? const SizedBox(),
      ),
    );
  }
}
